d2f

Macro d2f 

macro_rules! d2f {
    ($val:expr) => { ... };
}
Converts a Decimal value to f64 with error propagation.

This macro converts a Decimal type to an f64 floating-point value. It propagates any errors that might occur during conversion using the ? operator.

Parameters

  • $val - A Decimal value to be converted to f64