#[non_exhaustive]#[repr(u8)]pub enum BarrierType {
UpAndIn = 0,
UpAndOut = 1,
DownAndIn = 2,
DownAndOut = 3,
}Expand description
Describes the type of barrier for Barrier options.
Barrier options become active (“knock-in”) or inactive (“knock-out”) when the underlying asset reaches a specified price level.
Examples
use option_type::BarrierType;
let barrier = BarrierType::UpAndIn;
assert!(barrier.is_knock_in());
assert!(!barrier.is_knock_out());Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UpAndIn = 0
The option activates if the price goes above a certain level.
UpAndOut = 1
The option deactivates if the price goes above a certain level.
DownAndIn = 2
The option activates if the price goes below a certain level.
DownAndOut = 3
The option deactivates if the price goes below a certain level.
Implementations
Sourceimpl BarrierType
impl BarrierType
Sourcepub const fn is_knock_in(&self) -> bool
pub const fn is_knock_in(&self) -> bool
Returns true if this is a knock-in barrier (UpAndIn or DownAndIn).
Sourcepub const fn is_knock_out(&self) -> bool
pub const fn is_knock_out(&self) -> bool
Returns true if this is a knock-out barrier (UpAndOut or DownAndOut).