macro_rules! d2f {
($val:expr) => { ... };
}Expand description
Converts a Decimal value to f64 with error propagation.
This macro converts a Decimal type to an f64 floating-point value.
It propagates any errors that might occur during conversion using the ? operator.
Parameters
$val- A Decimal value to be converted to f64