#[repr(u8)]pub enum RainbowType {
BestOf = 0,
WorstOf = 1,
}Expand description
Describes the type of rainbow option based on how multiple assets are combined.
Rainbow options are multi-asset options where the payoff depends on the relative performance of two or more underlying assets.
Examples
use option_type::RainbowType;
let rainbow = RainbowType::default();
assert_eq!(rainbow, RainbowType::BestOf);Variants
BestOf = 0
Option on the maximum of multiple assets. Call payoff: max(max(S1, S2, …, Sn) - K, 0) Put payoff: max(K - max(S1, S2, …, Sn), 0)
WorstOf = 1
Option on the minimum of multiple assets. Call payoff: max(min(S1, S2, …, Sn) - K, 0) Put payoff: max(K - min(S1, S2, …, Sn), 0)
Implementations
Sourceimpl RainbowType
impl RainbowType
Sourcepub const fn is_best_of(&self) -> bool
pub const fn is_best_of(&self) -> bool
Returns true if this is a BestOf rainbow option.
Sourcepub const fn is_worst_of(&self) -> bool
pub const fn is_worst_of(&self) -> bool
Returns true if this is a WorstOf rainbow option.